"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Blip = void 0;
const Vector3_1 = require("../../share/Vector3");
class Blip {
    constructor(identifier) {
        this.identifier = identifier;
    }
    GetIdentifier() {
        return this.identifier;
    }
    static Create(identifier, name, sprite, rotation, shortRange, scale) {
        const blip = new Blip(identifier);
        blip.sprite = sprite;
        blip.name = name;
        blip.IsShortRange = shortRange;
        blip.rotation = rotation;
        blip.scale = scale;
        return blip;
    }
    static Coord(location, { name = "Blip Coords", sprite = 1, shortRange = true, scale = 1.0, rotation = 0 }) {
        const identifier = AddBlipForCoord(location.x, location.y, location.z);
        const blip = Blip.Create(identifier, name, sprite, rotation, shortRange, scale);
        return blip;
    }
    static Area(location, { name = "Blip Area", sprite = 1, shortRange = true, scale = 1.0, rotation = 0, width = 10, height = 10 }) {
        const identifier = AddBlipForArea(location.x, location.y, location.z, width, height);
        const blip = Blip.Create(identifier, name, sprite, rotation, shortRange, scale);
        return blip;
    }
    static Entity(entityId, { name = "Blip Entity", sprite = 1, shortRange = true, scale = 1.0, rotation = 0 }) {
        const identifier = AddBlipForEntity(entityId);
        const blip = Blip.Create(identifier, name, sprite, rotation, shortRange, scale);
        return blip;
    }
    static Radius(location, { name = "Blip Radius", sprite = 1, shortRange = true, scale = 1.0, rotation = 0, radius = 10 }) {
        const identifier = AddBlipForRadius(location.x, location.y, location.z, radius);
        const blip = Blip.Create(identifier, name, sprite, rotation, shortRange, scale);
        return blip;
    }
    static Pickup(pickupId, { name = "Blip Pickup", sprite = 1, shortRange = true, scale = 1.0, rotation = 0 }) {
        const identifier = AddBlipForPickup(pickupId);
        const blip = Blip.Create(identifier, name, sprite, rotation, shortRange, scale);
        return blip;
    }
    static BlipFromEntity(entityId) {
        const identifier = GetBlipFromEntity(entityId);
        return new Blip(identifier);
    }
    get Coord() {
        const coord = GetBlipInfoIdCoord(this.identifier);
        return new Vector3_1.Vector3(coord[0], coord[1], coord[2]);
    }
    SetCoord(location) {
        SetBlipCoords(this.identifier, location.x, location.y, location.z);
    }
    set coord(location) {
        this.SetCoord(location);
    }
    SetRotation(rotation) {
        SetBlipRotation(this.identifier, rotation);
    }
    set rotation(rotation) {
        this.SetRotation(rotation);
    }
    GetSprite() {
        return GetBlipSprite(this.identifier);
    }
    SetSprite(spriteId) {
        SetBlipSprite(this.identifier, spriteId);
    }
    set sprite(spriteId) {
        this.SetSprite(spriteId);
    }
    SetScale(scale) {
        SetBlipScale(this.identifier, scale);
    }
    set scale(scale) {
        this.SetScale(scale);
    }
    SetShortRange(shortRange) {
        SetBlipAsShortRange(this.identifier, shortRange);
    }
    get IsShortRange() {
        return IsBlipShortRange(this.identifier);
    }
    set IsShortRange(shortRange) {
        this.SetShortRange(shortRange);
    }
    SetName(name) {
        BeginTextCommandSetBlipName('STRING');
        AddTextComponentSubstringPlayerName(name);
        EndTextCommandSetBlipName(this.identifier);
    }
    set name(name) {
        this.SetName(name);
    }
}
exports.Blip = Blip;
